@@ -439,7 +439,7 @@ class TC_00_Appmenus(unittest.TestCase):
                 f.read()
             )
 
-        self.assertEquals(len(mock_subprocess.mock_calls), 1)
+        mock_subprocess.assert_called_once()
         args = mock_subprocess.call_args[0][0]
         self.assertEqual(
             args[:3],
@@ -488,7 +488,7 @@ class TC_00_Appmenus(unittest.TestCase):
                 f.read()
             )
 
-        self.assertEquals(len(mock_subprocess.mock_calls), 1)
+        mock_subprocess.assert_called_once()
         args = mock_subprocess.call_args[0][0]
         self.assertEqual(
             args[:3],
@@ -514,7 +514,6 @@ class TC_00_Appmenus(unittest.TestCase):
         self.appvm.virt_mode = 'pvh'
         self.appvm.run_service = _run
         self.appvm.log = unittest.mock.Mock()
-        self.appvm.log.warning = print
         appmenus = {
             'org.gnome.Cheese': {
                 'Name': 'Cheese',
